@@ -23,13 +23,13 @@ impl User {
     }
 }
 
-impl Entity for User {
-    fn id(&self) -> &ID {
-        &self.id
+impl Entity<ID> for User {
+    fn id(&self) -> ID {
+        self.id.clone()
     }
 }
 
-impl Meta for User {
+impl Meta<ID> for User {
     fn metadata(&self) -> &Metadata {
         &self.metadata
     }
@@ -48,5 +48,5 @@ pub enum UserIntegrationProvider {
 pub struct UserGoogleIntegrationData {
     pub refresh_token: String,
     pub access_token: String,
-    pub access_token_expires_ts: usize,
+    pub access_token_expires_ts: i64,
 }
